1.0.0 API documentation: quaternion_transform.hpp Source File

| 1.0.0 API documentation

quaternion_transform.hpp
Go to the documentation of this file.
1
18 #pragma once
19
20 // Dependency:
21 #include "../common.hpp"
22 #include "../trigonometric.hpp"
23 #include "../geometric.hpp"
24
25 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
26 # pragma message("GLM: GLM_EXT_quaternion_transform extension included")
27 #endif
28
29 namespace glm
30 {
33
42 template<typename T, qualifier Q>
43 GLM_FUNC_DECL qua<T, Q> rotate(qua<T, Q> const& q, T const& angle, vec<3, T, Q> const& axis);
45 } //namespace glm
46
47 #include "quaternion_transform.inl"
glm::angle
GLM_FUNC_DECL T angle(qua< T, Q > const &x)
Returns the quaternion rotation angle.
glm::axis
GLM_FUNC_DECL vec< 3, T, Q > axis(qua< T, Q > const &x)
Returns the q rotation axis.
glm::rotate
GLM_FUNC_DECL qua< T, Q > rotate(qua< T, Q > const &q, T const &angle, vec< 3, T, Q > const &axis)
Rotates a quaternion from a vector of 3 components axis and an angle.